Tutorials
=========


Jupyter (formerly IPython) notebooks
------------------------------------

A series of short tutorials is available as `Jupyter <https://jupyter.org/>`_
(former `IPython notebook <http://ipython.org/notebook.html>`_) notebooks that
present the main functionality and provide real-life examples

* `Intorduction to mendeleev <http://nbviewer.ipython.org/url/bitbucket.org/lukaszmentel/mendeleev/raw/tip/docs/ipynb/intro_to_mendeleev.ipynb>`_
* `Retrieving tables into DataFrames <http://nbviewer.ipython.org/url/bitbucket.org/lukaszmentel/mendeleev/raw/tip/docs/ipynb/tables.ipynb>`_
* `Plotting periodic tables <http://nbviewer.ipython.org/url/bitbucket.org/lukaszmentel/mendeleev/raw/tip/docs/ipynb/plotting_tutorial.ipynb>`_
